@@ -13,7 +13,7 @@ stemmer = LancasterStemmer()
 
 class ChatBot():
     
-    def __init__(self, dataSource, Dev):
+    def __init__(self, dataSource, Dev, epoch = 1000):
         ####Initializations####
         global data
         global words
@@ -76,17 +76,20 @@ class ChatBot():
         with open("data.pickle","wb") as model:
             pickle.dump((words, labels, docsX, docsY),model)
 
-        tensorflow.reset_default_graph()
-        dnnIn = tflearn.input_data(shape=[None , len(training[0])])
-        layer1 = tflearn.fully_connected(dnnIn, 8)
-        layer2 = tflearn.fully_connected(layer1, 8)
-        layer3 = tflearn.fully_connected(layer2, 8)
-        layer4 = tflearn.fully_connected(layer3, 8)
-        nNet = tflearn.fully_connected(layer4, len(output[0]), activation = "softmax")
-        reggModel = tflearn.regression(nNet)
-
-        self.model = tflearn.DNN(reggModel)
-        self.model.fit(training, output, n_epoch = 1000, batch_size=8, show_metric = True)
+        try:
+            self.model.load("model.tflearn")
+        except:
+            tensorflow.reset_default_graph()
+            dnnIn = tflearn.input_data(shape=[None , len(training[0])])
+            layer1 = tflearn.fully_connected(dnnIn, 8)
+            layer2 = tflearn.fully_connected(layer1, 8)
+            layer3 = tflearn.fully_connected(layer2, 8)
+            layer4 = tflearn.fully_connected(layer3, 8)
+            nNet = tflearn.fully_connected(layer4, len(output[0]), activation = "softmax")
+            reggModel = tflearn.regression(nNet)
+            self.model = tflearn.DNN(reggModel)
+            self.model.fit(training, output, n_epoch = epoch, batch_size=8, show_metric = True)
+            self.model.save("model.tflearn")
 
     def words_list(self, s, words):
         if dvMode:
